==> envg-0.0.5-py3-none-any.whl: envg/secrets.py <==
"""System Environment Variables."""
__all__ = (
    "GIT",
    "INTERNET",
    "EMAIL",
    "ORG",
    "TOKEN",
    "HTTPASSWD_BCRYPT_INTERNET",

    "CLOUDFLARE_ACCOUNT_ID",
    "CLOUDFLARE_API_KEY",
    "CLOUDFLARE_API_TOKEN",
    "CF_CA_KEY",
    "CLOUDFLARE_EMAIL",
    "CF_ZONE_ID",
    "CF_API_EMAIL",
    "CF_API_DOMAIN",

    "DOCKER_HUB_TOKEN",
    "DOCKER_SYNC_TOKEN",

    "DOPPLER_TOKEN",
    "DOPPLER_ENV",

    "DUCKDNS_TOKEN",

    "FLIT_PASSWORD",
    "FLIT_USERNAME",

    "GH_TOKEN",

    "GITHUB_TOKEN",

    "HOMEBREW_GITHUB_API_TOKEN",

    "ID_RSA",
    "ID_RSA_PUB",

    "JETBRAINS_PERMANET_TOKEN",

    "NPM_EMAIL",
    "NPM_REGISTRY",
    "NPM_SCOPE",
    "NPM_TOKEN",
    "NPM_USER",
    "NPM_PUBLISH",

    "OPENAI_API_KEY",
    "OPENAI_KEY",

    "PYPI_API_TOKEN",
    "PYPI_CLEANUP_PASSWORD",

    "SCALEWAY_SECRET_KEY",
    "SCALEWAY_ACCESS_KEY",
    "SCW_TOKEN",
    "SCALEWAY_ORGANIZATION_ID",
    "SCALEWAY_ENDPOINT",

    "TWINE_PASSWORD",
    "TWINE_USER",

    "TWITTER_CONSUMER_API_KEY",
    "TWITTER_CONSUMER_API_SECRET_KEY",
    "TWITTER_ACCESS_TOKEN",
    "TWITTER_ACCESS_TOKEN_SECRET",

    "VERCEL_TOKEN",

    "VULTR_API_KEY",
)

from envg.main import environment

GIT: str
"""GitHub User"""
INTERNET: str
"""Internet Password"""
EMAIL: str
"""User Email"""
ORG: str
"""GitHub Organization"""
TOKEN: str
"""GitHub Token"""
HTTPASSWD_BCRYPT_INTERNET: str
"""Bcrypt Http User Password"""

CLOUDFLARE_ACCOUNT_ID: str
CLOUDFLARE_API_KEY: str
CLOUDFLARE_API_TOKEN: str
CF_CA_KEY: str
CLOUDFLARE_EMAIL: str
CF_ZONE_ID: str
CF_API_EMAIL: str
CF_API_DOMAIN: str

DOCKER_HUB_TOKEN: str
DOCKER_SYNC_TOKEN: str

DOPPLER_TOKEN: str
DOPPLER_ENV: str

DUCKDNS_TOKEN: str

FLIT_PASSWORD: str
FLIT_USERNAME: str

GH_TOKEN: str

GITHUB_TOKEN: str

HOMEBREW_GITHUB_API_TOKEN: str

ID_RSA: str
ID_RSA_PUB: str

JETBRAINS_PERMANET_TOKEN: str

NPM_EMAIL: str
NPM_REGISTRY: str
NPM_SCOPE: str
NPM_TOKEN: str
NPM_USER: str
NPM_PUBLISH: str

OPENAI_API_KEY: str
OPENAI_KEY: str

PYPI_API_TOKEN: str
PYPI_CLEANUP_PASSWORD: str

SCALEWAY_SECRET_KEY: str
SCALEWAY_ACCESS_KEY: str
SCW_TOKEN: str
SCALEWAY_ORGANIZATION_ID: str
SCALEWAY_ENDPOINT: str

TWINE_PASSWORD: str
TWINE_USER: str

TWITTER_CONSUMER_API_KEY: str
TWITTER_CONSUMER_API_SECRET_KEY: str
TWITTER_ACCESS_TOKEN: str
TWITTER_ACCESS_TOKEN_SECRET: str

VERCEL_TOKEN: str

VULTR_API_KEY: str

environment()

==> envg-0.0.10-py3-none-any.whl: envg/secrets.py <==
"""System Environment Variables."""
__all__ = (
    "GIT",
    "INTERNET",
    "EMAIL",
    "ORG",
    "TOKEN",
    "HTTPASSWD_BCRYPT_INTERNET",

    "CLOUDFLARE_ACCOUNT_ID",
    "CLOUDFLARE_API_KEY",
    "CLOUDFLARE_API_TOKEN",
    "CF_CA_KEY",
    "CLOUDFLARE_EMAIL",
    "CF_ZONE_ID",
    "CF_API_EMAIL",
    "CF_API_DOMAIN",

    "DOCKER_HUB_TOKEN",
    "DOCKER_SYNC_TOKEN",

    "DOPPLER_TOKEN",
    "DOPPLER_ENV",

    "DUCKDNS_TOKEN",

    "FLIT_PASSWORD",
    "FLIT_USERNAME",

    "GH_TOKEN",

    "GITHUB_TOKEN",

    "HOMEBREW_GITHUB_API_TOKEN",

    "ID_RSA",
    "ID_RSA_PUB",

    "JETBRAINS_PERMANENT_TOKEN",

    "NPM_EMAIL",
    "NPM_REGISTRY",
    "NPM_SCOPE",
    "NPM_TOKEN",
    "NPM_USER",
    "NPM_PUBLISH",

    "OPENAI_API_KEY",
    "OPENAI_KEY",

    "PYPI_API_TOKEN",
    "PYPI_CLEANUP_PASSWORD",

    "SCALEWAY_SECRET_KEY",
    "SCALEWAY_ACCESS_KEY",
    "SCW_TOKEN",
    "SCALEWAY_ORGANIZATION_ID",
    "SCALEWAY_ENDPOINT",

    "TWINE_PASSWORD",
    "TWINE_USER",

    "TWITTER_CONSUMER_API_KEY",
    "TWITTER_CONSUMER_API_SECRET_KEY",
    "TWITTER_ACCESS_TOKEN",
    "TWITTER_ACCESS_TOKEN_SECRET",

    "VERCEL_TOKEN",

    "VULTR_API_KEY",
)

from envg.main import environment

GIT: str
"""GitHub User"""
INTERNET: str
"""Internet Password"""
EMAIL: str
"""User Email"""
ORG: str
"""GitHub Organization"""
TOKEN: str
"""GitHub Token"""
HTTPASSWD_BCRYPT_INTERNET: str
"""Bcrypt Http User Password"""

CLOUDFLARE_ACCOUNT_ID: str
CLOUDFLARE_API_KEY: str
CLOUDFLARE_API_TOKEN: str
CF_CA_KEY: str
CLOUDFLARE_EMAIL: str
CF_ZONE_ID: str
CF_API_EMAIL: str
CF_API_DOMAIN: str

DOCKER_HUB_TOKEN: str
DOCKER_SYNC_TOKEN: str

DOPPLER_TOKEN: str
DOPPLER_ENV: str

DUCKDNS_TOKEN: str

FLIT_PASSWORD: str
FLIT_USERNAME: str

GH_TOKEN: str

GITHUB_TOKEN: str

HOMEBREW_GITHUB_API_TOKEN: str

ID_RSA: str
ID_RSA_PUB: str

JETBRAINS_PERMANENT_TOKEN: str

NPM_EMAIL: str
NPM_REGISTRY: str
NPM_SCOPE: str
NPM_TOKEN: str
NPM_USER: str
NPM_PUBLISH: str

OPENAI_API_KEY: str
OPENAI_KEY: str

PYPI_API_TOKEN: str
PYPI_CLEANUP_PASSWORD: str

SCALEWAY_SECRET_KEY: str
SCALEWAY_ACCESS_KEY: str
SCW_TOKEN: str
SCALEWAY_ORGANIZATION_ID: str
SCALEWAY_ENDPOINT: str

TWINE_PASSWORD: str
TWINE_USER: str

TWITTER_CONSUMER_API_KEY: str
TWITTER_CONSUMER_API_SECRET_KEY: str
TWITTER_ACCESS_TOKEN: str
TWITTER_ACCESS_TOKEN_SECRET: str

VERCEL_TOKEN: str

VULTR_API_KEY: str

environment()
